@@ -4,7 +4,7 @@ use strict;
 use 5.002;
 
 use vars qw($VERSION $AUTOLOAD);
-$VERSION = '1.18';
+$VERSION = '1.19';
 
 use overload	'""'	=>	\&getTable,
 				fallback => undef;
@@ -216,7 +216,7 @@ boundaries extra rows and/or columns are created automatically.
 
 Sets the horizontal alignment for the cell.
 
-=item setCellVAlign(row_num, col_num, [CENTER|TOP|BOTTOM])
+=item setCellVAlign(row_num, col_num, [CENTER|TOP|BOTTOM|MIDDLE|BASELINE])
 
 Sets the vertical alignment for the cell.
 
@@ -298,7 +298,7 @@ to increase the number of rows.
 
 Applies setCellAlign over the entire column.
 
-=item setColVAlign(col_num, [CENTER|TOP|BOTTOM])
+=item setColVAlign(col_num, [CENTER|TOP|BOTTOM|MIDDLE|BASELINE])
 
 Applies setCellVAlign over the entire column.
 
@@ -354,7 +354,7 @@ to increase the number of columns.
 
 Applies setCellAlign over the entire row.
 
-=item setRowVAlign(row_num, [CENTER|TOP|BOTTOM])
+=item setRowVAlign(row_num, [CENTER|TOP|BOTTOM|MIDDLE|BASELINE])
 
 Applies setCellVAlign over the entire row.
 
@@ -567,8 +567,6 @@ $self->{"table:cellhead"} = {};
 # If paramter list is a hash (of the form -param=>value, ...)
 if (defined $_[0] && $_[0] =~ /^-/) {
     my %flags = @_;
-    $self->{rows} = $flags{-rows} || 0;
-    $self->{cols} = $flags{-cols} || 0;
     $self->{border} = defined $flags{-border} && _is_validnum($flags{-border}) ? $flags{-border} : undef;
     $self->{align} = $flags{-align} || undef;
     $self->{rules} = $flags{-rules} || undef;
@@ -579,6 +577,7 @@ if (defined $_[0] && $_[0] =~ /^-/) {
     $self->{width} = $flags{-width} || undef;
     $self->{cellspacing} = defined $flags{-spacing} && _is_validnum($flags{-spacing}) ? $flags{-spacing} : undef;
     $self->{cellpadding} = defined $flags{-padding} && _is_validnum($flags{-padding}) ? $flags{-padding} : undef;
+    $self->{cols} = $flags{-cols} || 0;
 
     if ($flags{-head})
     {
@@ -594,6 +593,12 @@ if (defined $_[0] && $_[0] =~ /^-/) {
       }
     }
 
+	if ($self->{rows}) {
+		$self->{rows} = $flags{-rows} if (defined $flags{-rows} && $self->{rows} < $flags{-rows});
+	} else {
+	    $self->{rows} = $flags{-rows} || 0;
+	}
+
 }
 elsif (ref $_[0])
 {
@@ -1132,12 +1137,13 @@ sub setCellAlign {
 }
 
 #-------------------------------------------------------
-# Subroutine:  	setCellVAlign(row_num, col_num, [CENTER|TOP|BOTTOM]) 
+# Subroutine:  	setCellVAlign(row_num, col_num, [CENTER|TOP|BOTTOM|MIDDLE|BASELINE]) 
 # Author:       Stacy Lacy	
 # Date:		30 Jul 1997
 # Modified:     13 Feb 2001 - Anthony Peacock for case insensitive
 #                             alignment parameters
 #                             (suggested by John Stumbles)
+# Modified:		22 Aug 2003 - Alejandro Juarez to add MIDDLE and BASELINE
 #-------------------------------------------------------
 sub setCellVAlign {
    my $self = shift;
@@ -1161,7 +1167,8 @@ sub setCellVAlign {
    }
 
    if (! (($valign eq "CENTER") || ($valign eq "TOP") || 
-          ($valign eq "BOTTOM"))) {
+          ($valign eq "BOTTOM")  || ($valign eq "MIDDLE") ||
+		  ($valign eq "BASELINE")) ) {
       print STDERR "$0:setCellVAlign:Invalid alignment type\n";
       return 0;
    }
@@ -1553,6 +1560,7 @@ sub setCellAttr {
 # 
 #-------------------------------------------------------
 
+
 #-------------------------------------------------------
 # Subroutine:  	addRow("cell 1 content" [, "cell 2 content",  ...]) 
 # Author:       Stacy Lacy	
